@@ -1,5 +1,8 @@
 # -*-Perl-*-
-# %W%	%G%
+# $Id: Sybperl.pm,v 1.28 1999/05/14 18:10:09 mpeppler Exp $
+#
+# From
+# 	@(#)Sybperl.pm	1.27	03/26/98
 #
 # Copyright (c) 1994-1995
 #   Michael Peppler
@@ -8,6 +11,39 @@
 #   or the Artistic License, copies of which should have accompanied
 #   your Perl kit.
 
+package Sybase::Sybperl;
+
+=head1 NAME
+
+Sybase::Sybperl - sybperl 1.0xx emulation module
+
+=head1 SYNOPSYS
+
+    require 'sybperl.pl';
+
+    $dbproc = dblogin($user, $pwd, $server);
+    dbcmd($dbproc, "select * from sysusers");
+    dbsqlexec($dbproc);
+    dbresults($dbproc);
+    while(@data = dbnextrow($dbproc)) {
+        print "@data\n";
+    }
+
+=head1 DESCRIPTION
+
+The Sybase::Sybperl module is provided to ease porting old perl4/sybperl 1.x
+programs to perl5. It is not recommended that this module be used for
+any new project. See L<Sybase::DBlib> or L<Sybase::CTlib> for alternatives.
+
+The old sybperl 1.0xx manpage is in the pod/sybperl-1.0xx.man in the
+sybperl source distribution.
+
+=head1 AUTHOR
+
+Michael Peppler F<E<lt>mpeppler@peppler.orgE<gt>>.
+
+=cut
+
 package Sybase::Sybperl::Attribs;
 
 sub TIESCALAR {
@@ -1128,6 +1164,74 @@ sub dbrpcinit
     $dbproc->dbrpcinit(@param);
 }
 
+sub dbreginit
+{
+    my(@param) = @_;
+    my($dbproc);
+
+    if(@param == 2)
+    {
+	$dbproc = shift(@param);
+    }
+    else
+    {
+	$dbproc = $default_db;
+    }
+
+    $dbproc->dbreginit(@param);
+}
+
+sub dbreglist
+{
+    my(@param) = @_;
+    my($dbproc);
+
+    if(@param == 1)
+    {
+	$dbproc = shift(@param);
+    }
+    else
+    {
+	$dbproc = $default_db;
+    }
+
+    $dbproc->dbreglist(@param);
+}
+
+sub dbregparam
+{
+    my(@param) = @_;
+    my($dbproc);
+
+    if(@param == 5)
+    {
+	$dbproc = shift(@param);
+    }
+    else
+    {
+	$dbproc = $default_db;
+    }
+
+    $dbproc->dbregparam(@param);
+}
+
+sub dbregexec
+{
+    my(@param) = @_;
+    my($dbproc);
+
+    if(@param == 2)
+    {
+	$dbproc = shift(@param);
+    }
+    else
+    {
+	$dbproc = $default_db;
+    }
+
+    $dbproc->dbregexec(@param);
+}
+
 sub dbwritetext
 {
     my(@params) = @_;
